Supported Resources
===================

.. toctree::
    :maxdepth: 2

   supported_datasets
   supported_features
   supported_scalers
   supported_models
   supported_optimizers
   supported_baselines
   supported_metrics
   supported_visualization